.. Note: This file is auto-generated using generate_credits.py

.. redirect-from:: /users/credits
.. redirect-from:: /users/project/credits

.. _credits:

*******
Credits
*******


Matplotlib was written by John D. Hunter, with contributions from an
ever-increasing number of users and developers.  The current lead developer is
Thomas A. Caswell, who is assisted by many `active developers
<https://www.openhub.net/p/matplotlib/contributors>`_.
Please also see our instructions on :doc:`/project/citing`.

The following is a list of contributors extracted from the
git revision control history of the project:

4over7,
816-8055,
A N U S H,
Aaron Boushley,
Aashil Patel,
AbdealiJK,
Abhinav Sagar,
Abhinuv Nitin Pitale,
Acanthostega,
Adam,
Adam Brown,
Adam Ginsburg,
Adam Gomaa,
Adam Heck,
Adam J. Stewart,
Adam Ortiz,
Adam Paszke,
Adam Ruszkowski,
Adam Williamson,
Adeel Hassan,
Aditya Malhotra,
Adrian Price-Whelan,
Adrien Chardon,
Adrien F. Vincent,
Ahmet Bakan,
Aitik Gupta,
AkM-2018,
Akiomi Kamakura,
Akshay Nair,
Alan Bernstein,
Alan Du,
Alberto,
Alejandro Dubrovsky,
Alejandro García,
Aleksey Bilogur,
Alex C. Szatmary,
Alex Henrie,
Alex Loew,
Alex Rothberg,
Alex Rudy,
AlexCav,
Alexander Buchkovsky,
Alexander Harnisch,
Alexander Rudy,
Alexander Schlüter,
Alexander Taylor,
Alexei Colin,
Alexis Bienvenüe,
Alexis de Almeida Coutinho,
Ali Mehdi,
Ali Uneri,
Alistair Muldal,
Allan Haldane,
Allen Downey,
Alon Hershenhorn,
Alvaro Sanchez,
Amit Aronovitch,
Amy,
Amy Roberts,
AmyTeegarden,
AndersonDaniel,
Andras Deak,
Andrea Bedini,
Andrea PIERRÉ,
Andreas C Mueller,
Andreas Gustafsson,
Andreas Hilboll,
Andreas Mayer,
Andreas Wallner,
Andrew Dawson,
Andrew Merrill,
Andrew Nelson,
Andrew Straw,
Andy Mastbaum,
Andy Zhu,
Ankur Dedania,
Anthony Scopatz,
Anton Akhmerov,
Antony Lee,
Antti Soininen,
Anubhav Shrimal,
Ao Liu (frankliuao),
Ardie Orden,
Arie,
Ariel Hernán Curiale,
Arnaud Gardelein,
Arpad Horvath,
Arthur Milchior,
Arthur Paulino,
Arvind,
Asaf Maman,
Aseem Bansal,
Ashley Whetter,
Atharva Khare,
Avinash Sharma,
Ayappan P,
BAKEZQ,
BH4,
BHT,
BTWS,
BaoGiang HoangVu,
Bas van Schaik,
Bastian Bechtold,
Behram Mistree,
Ben,
Ben Cohen,
Ben Gamari,
Ben Keller,
Ben Root,
Benedikt Daurer,
Benjamin Bengfort,
Benjamin Berg,
Benjamin Congdon,
Benjamin Reedlunn,
Bernhard M. Wiedemann,
Bharat123rox,
Bianca Gibson,
Binglin Chang,
Bingyao Liu,
Björn Dahlgren,
Blaise Thompson,
Boaz Mohar,
Bradley Dice,
Bradley M. Froehle,
Brandon Liu,
Braxton Lamey,
Brendan Zhang,
Brennan Magee,
Brett Cannon,
Brett Graham,
Brian Mattern,
Brian McFee,
Brian McLaughlin,
Brigitta Sipocz,
Bruno Beltran,
Bruno Pagani,
Bruno Zohreh,
Bryan Kok,
Byron Boulton,
CJ Carey,
Cameron Bates,
Cameron Davidson-Pilon,
Cameron Fackler,
Carissa Brittain,
Carl Michal,
Carlos Cerqueira,
Carsten Schelp,
Carwyn Pelley,
Casey Webster,
Casper da Costa-Luis,
Casper van der Wel,
Charles Moad,
Charles Ruan,
CharlesHe16,
Chen Karako,
Cho Yin Yong,
Chris,
Chris Barnes,
Chris Beaumont,
Chris G,
Chris Holdgraf,
Chris Zimmerman,
Christer Jensen,
Christian Baumann,
Christian Brodbeck,
Christian Brueffer,
Christian Stade-Schuldt,
Christoph Dann,
Christoph Deil,
Christoph Gohlke,
Christoph Hoffmann,
Christoph Pohl,
Christoph Reiter,
Christopher Bradshaw,
Cimarron Mittelsteadt,
Clemens Brunner,
Cody Scot,
Colin,
Colin Carroll,
Cong Ma,
Conner R. Phillips,
Constantine Evans,
Contextualist,
Corey Farwell,
Craig Citro,
Craig M,
Craig Tenney,
DaCoEx,
Dakota Blair,
Damian,
Damon McDougall,
Dan Hickstein,
Dan Zimmerman,
Dana,
DangoMelon,
Daniel,
Daniel C. Marcu,
Daniel Hyams,
Daniel Ingram,
Daniel Laidig,
Daniel O'Connor,
DanielMatu,
Daniele Nicolodi,
Danny Hermes,
Dara Adib,
Darren Dale,
DaveL17,
David A,
David Anderson,
David Chudzicki,
David Haberthür,
David Huard,
David Kaplan,
David Kent,
David Kua,
David Matos,
David Meyer,
David Poznik,
David Stansby,
David Trémouilles,
David Young,
Dean Malmgren,
Deng Tian,
Derek Kim,
Derek Tropf,
Devashish Deshpande,
Diego Leal Petrola,
Diego Mora Cespedes,
Dietmar Schwertberger,
Dietrich Brunn,
Dimitri Papadopoulos,
Divyam Madaan,
Dmitriy Fishman,
Dmitry Lupyan,
Dmitry Mottl,
Dmitry Shachnev,
Dominik Schmidt,
DonaldSeo,
Dora Fraeman Caswell,
DoriekeMG,
Dorota Jarecka,
Doug Blank,
Drew J. Sonne,
Duncan Macleod,
Dylan Cutler,
Dylan Evans,
E. G. Patrick Bos,
EBenkler,
Edin Salkovic,
Edoardo Pizzigoni,
Edouard Berthe,
Egor Panfilov,
Elan Ernest,
Elena Glassman,
Elias Pipping,
Elijah Schutz,
Elizabeth Seiver,
Ellert van der Velden,
Elliott Sales de Andrade,
Elvis Stansvik,
Emil Mikulic,
Emily FY,
Emlyn Price,
Eric Dill,
Eric Firing,
Eric Larson,
Eric Ma,
Eric O. LEBIGOT (EOL),
Eric Prestat,
Eric Relson,
Eric Wieser,
Erik Bray,
Erik M. Bray,
Erin Pintozzi,
Eugen Beck,
Eugene Yurtsev,
Evan Berkowitz,
Evan Davey,
Ewan Sutherland,
Ezra Peisach,
Fabian Kloosterman,
Fabian-Robert Stöter,
Fabien Maussion,
Fabio Zanini,
FedeMiorelli,
Federico Ariza,
Felipe,
Felix,
Felix Kohlgrüber,
Felix Nößler,
Felix Yan,
Fernando,
Fernando Perez,
Filip Dimitrovski,
Filipe Fernandes,
Florencia Noriega,
Florian Le Bourdais,
Florian Rhiem,
Forrest,
Francesco Montesano,
Francis Colas,
Franco Vaccari,
Francoise Provencher,
Frank Sauerburger,
Frank Yu,
François Magimel,
Gabe,
Gabriel Munteanu,
Gajendra Pal,
Gal Avineri,
Galen Lynch,
Gauravjeet,
Gaute Hope,
Gazing,
Gellule Xg,
Geoffrey Spear,
Geoffroy Billotey,
Georg Raiser,
Gerald Storer,
Gina,
Giovanni,
Gleb Fedorov,
Graeme Smecher,
Graham Poulter,
Greg Lucas,
Gregory Ashton,
Gregory R. Lee,
Grillard,
Grégory Lielens,
Guillaume Gay,
Guillermo Breto,
Gustavo Braganca,
Gustavo Goretkin,
HHest,
Hajoon Choi,
Hakan Kucukdereli,
Hannes Breytenbach,
Hanno Rein,
Hans Dembinski,
Hans Meine,
Hans Moritz Günther,
Hansin Ahuja,
Harnesser,
Harry Knight,
Harsh Sharma,
Harshal Prakash Patankar,
Harshit Patni,
Harutaka Kawamura,
Hassan Kibirige,
Hastings Greer,
Heath Henley,
Heiko Oberdiek,
Helder,
Henning Pohl,
Herbert Kruitbosch,
Hildo Guillardi Júnior,
Holger Peters,
Holtz Yan,
Hood Chatham,
Hubert Holin,
Hugo van Kemenade,
Iain-S,
Ian Hincks,
Ian Hunt-Isaak,
Ian Thomas,
Ida Hjorth,
Ignas Anikevicius (gns_ank),
Ildar Akhmetgaleev,
Ilia Kurenkov,
Illviljan,
Ilya Flyamer,
Ilya V. Schurov,
ImSoErgodic,
ImportanceOfBeingErnest,
Inception95,
Ingo Fründ,
Ioannis Filippidis,
Isa Hassen,
Isaac Schwabacher,
Isaac Slavitt,
Isha Mehta,
Ismo Toijala,
Isuru Fernando,
ItsRLuo,
J Alammar,
J. Goutin,
J. Scott Berg,
Jaap Versteegh,
Jack Kelly,
Jacob McDonald,
Jacobson Okoro,
Jae-Joon Lee,
Jaime Fernandez,
Jake Bowhay,
Jake Lee,
Jake Lishman,
Jake VanderPlas,
Jake Vanderplas,
Jakub Klus,
James A. Bednar,
James Adams,
James Pallister,
James R. Evans,
JamesMakela,
Jamie Nunez,
Jan S. (Milania1),
Jan Schlüter,
Jan Schulz,
Jan-Hendrik Müller,
Jan-Philip Gehrcke,
Jan-willem De Bleser,
Janakarajan Natarajan,
Jann Paul Mattern,
Jarrod Millman,
Jascha Ulrich,
Jash Shah,
Jason Grout,
Jason King,
Jason Liw Yan Chong,
Jason Miller,
Jason Neal,
Jason Zheng,
Javad,
Jay Joshi,
JayP16,
Jean-Benoist Leger,
Jeff Beck,
Jeff Lutgen,
Jeff Whitaker,
Jeffrey Bingham,
Jeffrey Hokanson @ Loki,
JelsB,
Jens Hedegaard Nielsen,
Jeremy Fix,
Jeremy O'Donoghue,
Jeremy Thurgood,
Jerome F. Villegas,
Jeroonk,
Jessica B. Hamrick,
Jiahao Chen,
Jim Radford,
Jirka Hladky,
Jochen Voss,
Jody Klymak,
Joe Kington,
Joel B. Mohler,
Joel Frederico,
Joel Wanner,
Johan von Forstner,
Johannes H. Jensen,
Johannes Wienke,
John Hoffman,
John Hunter,
John Losito,
John Peloquin,
John Vandenberg,
Johnny Gill,
JojoBoulix,
Jon Haitz Legarreta Gorroño,
Jonas Camillus Jeppesen,
Jonathan Waltman,
Jonathan Yong,
Jorge Moraleda,
Jorrit Wronski,
Joscha Reimer,
Joschua-Conrad,
Jose Manuel Martí,
Josef Heinen,
Joseph Albert,
Joseph Fox-Rabinovitz,
Joseph Jon Booker,
Joseph Martinot-Lagarde,
Joshua Taillon,
José Ricardo,
Jouni K. Seppänen,
Joy Bhalla,
Juan Nunez-Iglesias,
Juanjo Bazán,
Julia Sprenger,
Julian Mehne,
Julian Taylor,
Julian V. Modesto,
JulianCienfuegos,
Julien Lhermitte,
Julien Schueller,
Julien Woillez,
Julien-Charles Lévesque,
Jun Tan,
Justin Cai,
Jörg Dietrich,
KIU Shueng Chuan,
KM Goh,
Kacper Kowalik (Xarthisius),
Kai Muehlbauer,
Kanchana Ranasinghe,
Kanwar245,
Katrin Leinweber,
Katy Huff,
Kayla Ngan,
Keerysanth Sribaskaran,
Ken McIvor,
Kenneth Ma,
Kent,
Kent Gauen,
Kevin Chan,
Kevin Davies,
Kevin Ji,
Kevin Keating,
Kevin Mader,
Kevin Rose,
Kexuan Sun,
Kieran Ramos,
Kimmo Palin,
Kinshuk Dua,
Kjartan Myrdal,
Kjell Le,
Klara Gerlei,
Konrad Förstner,
Konstantin Popov,
Konstantin Tretyakov,
Kristen M. Thyng,
Kyle Bridgemohansingh,
Kyle Sunden,
Kyler Brown,
Lance Hepler,
Laptop11_ASPP2016,
Larry Bradley,
Laurent Thomas,
Lawrence D'Anna,
Lee Johnston,
Leeonadoh,
Lennart Fricke,
Leo Singer,
Leon Loopik,
Leon Yin,
LevN0,
Levi Kilcher,
Liam Brannigan,
Liam Toney,
Lion Krischer,
Lionel Miller,
Lodato Luciano,
Lori J,
Loïc Estève,
Loïc Séguin-C,
Luca Verginer,
Lucy Liu,
Luis Pedro Coelho,
Luke Davis,
Léonard Gérard,
Maarten Baert,
Maciej Dems,
Madhav Humagain,
Magnus Nord,
Maik Riechert,
Majid alDosari,
Maksym P,
MalikIdreesHasa,
Manan Kevadiya,
Manish Devgan,
Manuel GOACOLOU,
Manuel Jung,
Manuel Metz,
Manuel Nuno Melo,
Maoz Gelbart,
Marat Kopytjuk,
Marc Abramowitz,
Marcel Martin,
Marco Gorelli,
Marco Rigobello,
Marcos Duarte,
Marek Rudnicki,
Maria-Alexandra Ilie,
Marianne Corvellec,
Marin Gilles,
Mark Harfouche,
Mark Wolf,
Marko Baštovanović,
Markus Roth,
Markus Rothe,
Markus Wesslén,
Martin Dengler,
Martin Fitzpatrick,
Martin Spacek,
Martin Teichmann,
Martin Thoma,
Martin Ueding,
Mary Chris Go,
Massimo Santini,
Masud Rahman,
Mathieu Duponchelle,
Matt Giuca,
Matt Hancock,
Matt Klein,
Matt Li,
Matt Newville,
Matt Shen,
Matt Terry,
Matthew Bell,
Matthew Brett,
Matthew Emmett,
Matthew Petroff,
Matthias Bussonnier,
Matthias Geier,
Matthias Lüthi,
Matthieu Caneill,
MatthieuDartiailh,
Matti Picus,
Matěj Týč,
Max,
Max Chen,
Max Humber,
Max Shinn,
Maximilian Albert,
Maximilian Maahn,
Maximilian Nöthe,
Maximilian Trescher,
McToel,
MeeseeksMachine,
Mellissa Cross,
Mher Kazandjian,
Michael,
Michael Droettboom,
Michael Grupp,
Michael Jancsy,
Michael Sarahan,
Michael Scott Cuthbert,
Michael Seifert,
Michael Welter,
Michaël Defferrard,
Michał Górny,
Michele Mastropietro,
Michiel de Hoon,
Michka Popoff,
Mihai Anton,
Mike Henninger,
Mike Jarvis,
Mike Kaufman,
Mikhail Korobov,
MinRK,
Mingkai Dong,
Minty Zhang,
MirandaXM,
Miriam Sierig,
Mitar,
Mohammad Aflah Khan,
Molly Rossow,
Moritz Boehle,
Mudit Surana,
Muhammad Mehdi,
MuhammadFarooq1234,
Mykola Dvornik,
Naoya Kanai,
Nathan Goldbaum,
Nathan Musoke,
Nathaniel M. Beaver,
Navid C. Constantinou,
Neil,
Neil Crighton,
Neilzon Viloria,
Nelle Varoquaux,
Niall Robinson,
Nic Eggert,
Nicholas Devenish,
Nick Forrington,
Nick Garvey,
Nick Papior,
Nick Pope,
Nick Semenkovich,
Nico Schlömer,
Nicolas Courtemanche,
Nicolas P. Rougier,
Nicolas Pinto,
Nicolas Tessore,
Nik Quibin,
Nikita Kniazev,
Niklas Koep,
Nikolay Vyahhi,
Nils Werner,
Ninad Bhat,
Nora Moseman,
Norbert Nemec,
Norman Fomferra,
OceanWolf,
Oleg Selivanov,
Olga Botvinnik,
Oliver Natt,
Oliver Willekens,
Olivier Castany,
Om Sitapara,
Omar Chehab,
Oriol Abril,
Orso Meneghini,
Osarumwense,
Oscar Gustafsson,
Pamela Wu,
Pankaj Pandey,
Paramonov Andrey,
Parfenov Sergey,
Pascal Bugnion,
Pastafarianist,
Patrick Chen,
Patrick Feiring,
Patrick Marsh,
Patrick Shriwise,
PatrickFeiring,
Paul,
Paul Barret,
Paul Ganssle,
Paul Gierz,
Paul Hobson,
Paul Hoffman,
Paul Ivanov,
Paul J. Koprowski,
Paul Kirow,
Paul Romano,
Paul Seyfert,
Pauli Virtanen,
Pavel Fedin,
Pavol Juhas,
Per Parker,
Perry Greenfield,
Petar Mlinarić,
Pete Bachant,
Pete Huang,
Pete Peterson,
Peter Iannucci,
Peter Mackenzie-Helnwein,
Peter Mortensen,
Peter Schutt,
Peter St. John,
Peter Williams,
Peter Würtz,
Petr Danecek,
Phil Elson,
Phil Ruffwind,
Philip Schiff,
Philipp Arras,
Philipp Nagel,
Philippe Pinard,
Pierre Haessig,
Pierre Thibault,
Pierre de Buyl,
Pim Schellart,
Piti Ongmongkolkul,
Po,
Pranav Garg,
Pratyush Raj,
Przemysław Dąbek,
Puneeth Chaganti,
Péter Leéh,
QiCuiHub,
Qingpeng "Q.P." Zhang,
Quentin Peter,
RAKOTOARISON Herilalaina,
Ram Rachum,
Ramiro Gómez,
Randall Ung,
Randy Olson,
Raphael,
Rasmus Diederichsen,
Ratin_Kumar,
Rebecca W Perry,
Reinier Heeres,
Remi Rampin,
Ren Pang,
Rezangyal,
Ricardo Mendes,
Riccardo Di Maio,
Richard Gowers,
Richard Hattersley,
Richard Ji-Cathriner,
Richard Sheridan,
Richard Trieu,
Ricky,
Rike-Benjamin Schuppner,
Rishikesh,
Rob Harrigan,
Rob McDonald,
Robert Johansson,
Roberto Toro,
Robin Dunn,
Robin Neatherway,
Robin Wilson,
Rohan Walker,
Rohit Rawat,
Roland Wirth,
Roman Yurchak,
Ronald Hartley-Davies,
RoryIAngus,
Roy Smith,
Ruben Verweij,
Rui Lopes,
Russell Owen,
RutgerK,
Ruth Comer,
Ruth Nainggolan,
Ryan,
Ryan Blomberg,
Ryan D'Souza,
Ryan Dale,
Ryan May,
Ryan Morshead,
Ryan Nelson,
RyanPan,
SBCV,
Sadie Louise Bartholomew,
Sairam Pillai,
Saket Choudhary,
Salganos,
Salil Vanvari,
Salinder Sidhu,
Sam Tygier,
Sam Van Kooten,
Sam Vaughan,
SamSchott,
Sameer D'Costa,
Samesh Lakhotia,
Samson,
Samuel St-Jean,
Sander,
Sandro Tosi,
Scott Howard,
Scott Lasley,
Scott Lawrence,
Scott Shambaugh,
Scott Stevenson,
Sean Farley,
Sebastian Bullinger,
Sebastian Pinnau,
Sebastian Raschka,
Sebastián Vanrell,
Seraphim Alvanides,
Sergey B Kirpichev,
Sergey Kholodilov,
Sergey Koposov,
Seunghoon Park,
ShawnChen1996,
Siddhesh Poyarekar,
Sidharth Bansal,
Silviu Tantos,
Simon Cross,
Simon Gibbons,
Simon Hoxbro,
Simon Legner,
Skelpdar,
Skipper Seabold,
Slav Basharov,
Slava Ostroukh,
Snowhite,
SojiroFukuda,
Sourav Singh,
Spencer McCoubrey,
Spencer McIntyre,
Srihitha Maryada,
Stanley, Simon,
Stefan Appelhoff,
Stefan Lehmann,
Stefan Mitic,
Stefan Pfenninger,
Stefan van der Walt,
Stefanie Molin,
Stefano Rivera,
Steffen Rehberg,
Stephan Erb,
Stephane Raynaud,
Stephen Horst,
Stephen Sinclair,
Stephen-Chilcote,
Sterling Smith,
Steve Chaplin,
Steve Dower,
Steven G. Johnson,
Steven Munn,
Steven Silvester,
Steven Tilley,
Struan Murray,
Stuart Mumford,
Sven Eschlbeck,
Tadeo Corradi,
Taehoon Lee,
Takafumi Arakaki,
Takeshi Kanmae,
Tamas Gal,
Tanuj,
Taras Kuzyo,
Ted Drain,
Ted Petrou,
Terence Honles,
Terrence J. Katzenbaer,
Terrence Katzenbaer,
The Gitter Badger,
Thein Oo,
Thomas A Caswell,
Thomas Hisch,
Thomas Kluyver,
Thomas Lake,
Thomas Levine,
Thomas Mansencal,
Thomas Robitaille,
Thomas Spura,
Thomas VINCENT,
Thorsten Liebig,
Thorvald Johannessen,
Tian Xia,
Till Hoffmann,
Till Stensitzki,
Tim Gates,
Tim Hoffmann,
Timo Vanwynsberghe,
Tobia De Koninck,
Tobias Froehlich,
Tobias Hangleiter,
Tobias Hoppe,
Tobias Megies,
Todd Jennings,
Todd Miller,
Tom,
Tom Augspurger,
Tom Charrett,
Tom Dupré la Tour,
Tom Flannaghan,
Tom Neep,
Tomas Fiers,
Tomas Hrnciar,
Tomas Kazmar,
Tony S Yu,
Tor Colvin,
Tortar,
Travis Oliphant,
Trevor Bekolay,
Trish Gillett-Kawamoto,
Truong Pham,
Tuan Dung Tran,
Tyler Makaro,
Tyrone Xiong,
Ulrich Dobramysl,
Ulrich J. Herter,
Umair Idris,
Umar Javed,
Utkarshp1,
Uwe F. Mayer,
V. Armando Solé,
V. R,
Vadim Markovtsev,
Vagrant Cascadian,
Valentin Haenel,
Valentin Schmidt,
Valentin Valls,
Vedant Nanda,
Venkada,
Viacheslav Ostroukh,
Vidur Satija,
Viktor Kerkez,
Vincent Cuenca,
Vincent L.M. Mazoyer,
Vineyard,
Viraj Mohile,
Vishnu V K,
Vitaly Buka,
Vlad Korolev,
Vlad Seghete,
Vlas Sokolov,
Víctor Terrón,
Víctor Zabalza,
WANG Aiyong,
Warren Weckesser,
Wen Li,
Wendell Smith,
Werner F Bruhin,
Wes Campaigne,
Wieland Hoffmann,
Will Handley,
Will Silva,
William Granados,
William Mallard,
William Manley,
Wouter Overmeire,
Xianxiang Li,
Xiaowen Tang,
Xufeng Wang,
Yann Tambouret,
Yannic Schroeder,
Yao-Yuan Mao,
Yaron de Leeuw,
Yichao Yu,
Yo Yehudi,
Yu Feng,
Yue Zhihan,
Yun Liu,
Yunfei Yang,
Yuri D'Elia,
Yuval Langer,
Yuxin Wu,
Yuya,
Zac Hatfield-Dodds,
Zach Pincus,
Zair Mubashar,
Zbigniew Jędrzejewski-Szmek,
Zexi,
Zhili (Jerry) Pan,
Zulko,
aflah02,
agra,
ahed87,
akrherz,
alcinos,
alex,
alvarosg,
ambi7,
andrzejnovak,
andthum,
aneda,
anykraus,
aparamon,
arokem,
as691454,
aseagram,
ash13,
aszilagyi,
azure-pipelines[bot],
bakes,
bblay,
bduick,
bev-a-tron,
blackw1ng,
blah blah,
brut,
btang02,
buefox,
burrbull,
butterw,
cammil,
captainwhippet,
cavesdev,
cclauss,
ceelo777,
ch3rn0v,
chadawagner,
chaoyi1,
chebee7i,
chelseatroy,
chuanzhu xu,
cknd,
cldssty,
clintval,
dabana,
dahlbaek,
danielballan,
daniilS,
daronjp,
davidovitch,
daydreamt,
deeenes,
deepyaman,
dependabot[bot],
dj4t9n,
djdt,
dlmccaffrey,
domspad,
donald,
donchanee,
drevicko,
e-q,
ebenp,
ecotner,
elpres,
endolith,
esvhd,
et2010,
fardal,
ffteja,
fgb,
fibersnet,
fourpoints,
fredrik-1,
frenchwr,
fuzzythecat,
fvgoto,
gcallah,
gitj,
gluap,
gnaggnoyil,
goir,
goldstarwebs,
greg-roper,
gregorybchris,
gwin-zegal,
hannah,
helmiriawan,
henryhu123,
hugadams,
ikhebgeenaccount,
ilivni,
insertroar,
itziakos,
iury simoes-sousa,
jacob-on-github,
jayjoshi112711,
jb-leger,
jbbrokaw,
jbhopkins,
jdollichon,
jeetvora331,
jeffreypaul15,
jerrylui803,
jess,
jfbu,
jhelie,
jli,
joaonsg,
joelostblom,
john imperial,
johnthagen,
jonchar,
juan.gonzalez,
kate-perkins,
katrielester,
kcrisman,
keithbriggs,
kelsiegr,
kentcr,
kikocorreoso,
kir0ul,
kislovskiy,
klaus,
klonuo,
kramer65,
krishna katyal,
ksafran,
kshramt,
kwgchi,
lboogaard,
legitz7,
lepuchi,
lgfunderburk,
lichri12,
limtaesu,
linchiwei123,
lspvic,
luftek,
luz paz,
lzkelley,
majorwitty,
mamrehn,
mansoor96g,
marky,
martinRenou,
masamson,
mbyt,
mcelrath,
mcquin,
mdipierro,
mikhailov,
miquelastein,
mitch,
mlub,
mobando,
mromanie,
muahah,
myyc,
nathan78906,
navdeep rana,
nbrunett,
nemanja,
neok-m4700,
nepix32,
nickystringer,
njwhite,
nmartensen,
nwin,
ob,
ojeda-e,
pankajchetry1168,
pdubcali,
philip-sparks,
pibion,
pkienzle,
productivememberofsociety666,
profholzer,
pupssman,
pwohlhart,
rahiel,
ranjanm,
rebot,
reshamas,
rgbmrc,
rhoef,
rsnape,
ruin,
rvhbooth,
ryahern,
s0vereign,
s9w,
saksmito,
sandipanpanda,
scls19fr,
scott-vsi,
sdementen,
selormtamakloe,
serv-inc,
settheory,
sfroid,
shaunwbell,
simon-kraeusel,
simonpf,
sindunuragarp,
smheidrich,
sohero,
spiessbuerger,
stahlous,
stone,
stonebig,
sveneschlbeck,
switham,
sxntxn,
syngron,
takimata,
teresy,
theOehrly,
thoo,
thuvejan,
tmdavison,
tohc1,
tomoemon,
tonyyli,
torfbolt,
u55,
ugurthemaster,
ulijh,
ultra-andy,
vab9,
vbr,
vfdev-5,
vishalBindal,
vraelvrangr,
watkinrt,
woclass,
xbtsw,
xlilos,
xuanyuansen,
y1thof,
yeo,
yozhikoff,
yuanx749,
z0rgy,
zhangeugenia,
zhoubecky,
zitorelova,
znstrider,
Élie Gouzien,
Андрей Парамонов

Some earlier contributors not included above are (with apologies
to any we have missed):

Charles Twardy,
Gary Ruben,
John Gill,
David Moore,
Paul Barrett,
Jared Wahlstrand,
Jim Benson,
Paul Mcguire,
Andrew Dalke,
Nadia Dencheva,
Baptiste Carvello,
Sigve Tjoraand,
Ted Drain,
James Amundson,
Daishi Harada,
Nicolas Young,
Paul Kienzle,
John Porter,
and Jonathon Taylor.

Thanks to Tony Yu for the original logo design.

We also thank all who have reported bugs, commented on
proposed changes, or otherwise contributed to Matplotlib's
development and usefulness.
